UnwindSafe

Trait UnwindSafe 

1.41.0 ยท Source
pub auto trait UnwindSafe { }
A marker trait which represents โ€œpanic safeโ€ types in Rust.

This trait is implemented by default for many types and behaves similarly in terms of inference of implementation to the Send and Sync traits. The purpose of this trait is to encode what types are safe to cross a catch_unwind boundary with no fear of unwind safety.

What is unwind safety?

In Rust a function can โ€œreturnโ€ early if it either panics or calls a function which transitively panics. This sort of control flow is not always anticipated, and has the possibility of causing subtle bugs through a combination of two critical components:

  1. A data structure is in a temporarily invalid state when the thread panics.
  2. This broken invariant is then later observed.

Typically in Rust, it is difficult to perform step (2) because catching a panic involves either spawning a thread (which in turn makes it difficult to later witness broken invariants) or using the catch_unwind function in this module. Additionally, even if an invariant is witnessed, it typically isnโ€™t a problem in Rust because there are no uninitialized values (like in C or C++).

It is possible, however, for logical invariants to be broken in Rust, which can end up causing behavioral bugs. Another key aspect of unwind safety in Rust is that, in the absence of unsafe code, a panic cannot lead to memory unsafety.

That was a bit of a whirlwind tour of unwind safety, but for more information about unwind safety and how it applies to Rust, see an associated RFC.

What is UnwindSafe?

Now that weโ€™ve got an idea of what unwind safety is in Rust, itโ€™s also important to understand what this trait represents. As mentioned above, one way to witness broken invariants is through the catch_unwind function in this module as it allows catching a panic and then re-using the environment of the closure.

Simply put, a type T implements UnwindSafe if it cannot easily allow witnessing a broken invariant through the use of catch_unwind (catching a panic). This trait is an auto trait, so it is automatically implemented for many types, and it is also structurally composed (e.g., a struct is unwind safe if all of its components are unwind safe).

Note, however, that this is not an unsafe trait, so there is not a succinct contract that this trait is providing. Instead it is intended as more of a โ€œspeed bumpโ€ to alert users of catch_unwind that broken invariants may be witnessed and may need to be accounted for.

Who implements UnwindSafe?

Types such as &mut T and &RefCell<T> are examples which are not unwind safe. The general idea is that any mutable state which can be shared across catch_unwind is not unwind safe by default. This is because it is very easy to witness a broken invariant outside of catch_unwind as the data is simply accessed as usual.

Types like &Mutex<T>, however, are unwind safe because they implement poisoning by default. They still allow witnessing a broken invariant, but they already provide their own โ€œspeed bumpsโ€ to do so.

When should UnwindSafe be used?

It is not intended that most types or functions need to worry about this trait. It is only used as a bound on the catch_unwind function and as mentioned above, the lack of unsafe means it is mostly an advisory. The AssertUnwindSafe wrapper struct can be used to force this trait to be implemented for any closed over variables passed to catch_unwind.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Auto implementors



impl !UnwindSafe for core::io::Error



impl UnwindSafe for !



impl UnwindSafe for ()



impl UnwindSafe for Abi



impl UnwindSafe for AddrParseError



impl UnwindSafe for core::mem::Alignment



impl UnwindSafe for core::fmt::Alignment



impl UnwindSafe for AllocError



impl UnwindSafe for Array



impl UnwindSafe for AsciiChar



impl UnwindSafe for Assume



impl UnwindSafe for AtomicOrdering



impl UnwindSafe for BasicBlock



impl UnwindSafe for Bool



impl UnwindSafe for BorrowError



impl UnwindSafe for BorrowMutError



impl UnwindSafe for ByteStr



impl UnwindSafe for CStr



impl UnwindSafe for Char



impl UnwindSafe for CharCase



impl UnwindSafe for CharTryFromError



impl UnwindSafe for Const



impl UnwindSafe for CpuidResult



impl UnwindSafe for DebugAsHex



impl UnwindSafe for DecodeUtf16Error



impl UnwindSafe for Duration



impl UnwindSafe for DynTrait



impl UnwindSafe for DynTraitPredicate



impl UnwindSafe for core::io::Empty



impl UnwindSafe for Enum



impl UnwindSafe for core::fmt::Error



impl UnwindSafe for ErrorKind



impl UnwindSafe for core::char::EscapeDebug



impl UnwindSafe for core::ascii::EscapeDefault



impl UnwindSafe for core::char::EscapeDefault



impl UnwindSafe for core::char::EscapeUnicode



impl UnwindSafe for Field



impl UnwindSafe for FieldId



impl UnwindSafe for Float



impl UnwindSafe for FnPtr



impl UnwindSafe for FormattingOptions



impl UnwindSafe for FpCategory



impl UnwindSafe for FromBytesUntilNulError



impl UnwindSafe for FromBytesWithNulError



impl UnwindSafe for Generic



impl UnwindSafe for GenericType



impl UnwindSafe for GetDisjointMutError



impl UnwindSafe for core::arch::hexagon::v64::HvxVector



impl UnwindSafe for core::arch::hexagon::v128::HvxVector



impl UnwindSafe for core::arch::hexagon::v64::HvxVectorPair



impl UnwindSafe for core::arch::hexagon::v128::HvxVectorPair



impl UnwindSafe for core::arch::hexagon::v64::HvxVectorPred



impl UnwindSafe for core::arch::hexagon::v128::HvxVectorPred



impl UnwindSafe for Infallible



impl UnwindSafe for Int



impl UnwindSafe for IntErrorKind



impl UnwindSafe for IpAddr



impl UnwindSafe for Ipv4Addr



impl UnwindSafe for Ipv6Addr



impl UnwindSafe for Ipv6MulticastScope



impl UnwindSafe for Last



impl UnwindSafe for Layout



impl UnwindSafe for LayoutError



impl UnwindSafe for Lifetime



impl UnwindSafe for LocalWaker



impl UnwindSafe for Locality



impl UnwindSafe for OneSidedRangeBound



impl UnwindSafe for core::cmp::Ordering



impl UnwindSafe for core::sync::atomic::Ordering



impl UnwindSafe for ParseBoolError



impl UnwindSafe for ParseCharError



impl UnwindSafe for ParseFloatError



impl UnwindSafe for ParseIntError



impl UnwindSafe for PhantomPinned



impl UnwindSafe for Pointer



impl UnwindSafe for RangeFull



impl UnwindSafe for RawWaker



impl UnwindSafe for RawWakerVTable



impl UnwindSafe for Reference



impl UnwindSafe for core::io::Repeat



impl UnwindSafe for ReturnToArg



impl UnwindSafe for SY



impl UnwindSafe for SearchStep



impl UnwindSafe for Sign



impl UnwindSafe for SimdAlign



impl UnwindSafe for Sink



impl UnwindSafe for SipHasher



impl UnwindSafe for Slice



impl UnwindSafe for SocketAddr



impl UnwindSafe for SocketAddrV4



impl UnwindSafe for SocketAddrV6



impl UnwindSafe for Str



impl UnwindSafe for Struct



impl UnwindSafe for ToCasefold



impl UnwindSafe for ToLowercase



impl UnwindSafe for ToTitlecase



impl UnwindSafe for ToUppercase



impl UnwindSafe for Trait



impl UnwindSafe for TryFromCharError



impl UnwindSafe for TryFromFloatSecsError



impl UnwindSafe for TryFromIntError



impl UnwindSafe for TryFromSliceError



impl UnwindSafe for Tuple



impl UnwindSafe for Type



impl UnwindSafe for TypeId



impl UnwindSafe for TypeKind



impl UnwindSafe for Union



impl UnwindSafe for UnwindActionArg



impl UnwindSafe for UnwindTerminateReason



impl UnwindSafe for Utf8Error



impl UnwindSafe for Variant



impl UnwindSafe for Waker



impl UnwindSafe for __m128



impl UnwindSafe for __m256



impl UnwindSafe for __m512



impl UnwindSafe for __m128bh



impl UnwindSafe for __m128d



impl UnwindSafe for __m128h



impl UnwindSafe for __m128i



impl UnwindSafe for __m256bh



impl UnwindSafe for __m256d



impl UnwindSafe for __m256h



impl UnwindSafe for __m256i



impl UnwindSafe for __m512bh



impl UnwindSafe for __m512d



impl UnwindSafe for __m512h



impl UnwindSafe for __m512i



impl UnwindSafe for __tile1024i



impl UnwindSafe for bf16



impl UnwindSafe for bool



impl UnwindSafe for c_void



impl UnwindSafe for char



impl UnwindSafe for f16



impl UnwindSafe for f32



impl UnwindSafe for f64



impl UnwindSafe for f16x2



impl UnwindSafe for f128



impl UnwindSafe for float16x4_t



impl UnwindSafe for float16x4x2_t



impl UnwindSafe for float16x4x3_t



impl UnwindSafe for float16x4x4_t



impl UnwindSafe for float16x8_t



impl UnwindSafe for float16x8x2_t



impl UnwindSafe for float16x8x3_t



impl UnwindSafe for float16x8x4_t



impl UnwindSafe for float32x2_t



impl UnwindSafe for float32x2x2_t



impl UnwindSafe for float32x2x3_t



impl UnwindSafe for float32x2x4_t



impl UnwindSafe for float32x4_t



impl UnwindSafe for float32x4x2_t



impl UnwindSafe for float32x4x3_t



impl UnwindSafe for float32x4x4_t



impl UnwindSafe for float64x1_t



impl UnwindSafe for float64x1x2_t



impl UnwindSafe for float64x1x3_t



impl UnwindSafe for float64x1x4_t



impl UnwindSafe for float64x2_t



impl UnwindSafe for float64x2x2_t



impl UnwindSafe for float64x2x3_t



impl UnwindSafe for float64x2x4_t



impl UnwindSafe for i8



impl UnwindSafe for i16



impl UnwindSafe for i32



impl UnwindSafe for i64



impl UnwindSafe for i128



impl UnwindSafe for int8x8_t



impl UnwindSafe for int8x8x2_t



impl UnwindSafe for int8x8x3_t



impl UnwindSafe for int8x8x4_t



impl UnwindSafe for int8x16_t



impl UnwindSafe for int8x16x2_t



impl UnwindSafe for int8x16x3_t



impl UnwindSafe for int8x16x4_t



impl UnwindSafe for int16x4_t



impl UnwindSafe for int16x4x2_t



impl UnwindSafe for int16x4x3_t



impl UnwindSafe for int16x4x4_t



impl UnwindSafe for int16x8_t



impl UnwindSafe for int16x8x2_t



impl UnwindSafe for int16x8x3_t



impl UnwindSafe for int16x8x4_t



impl UnwindSafe for int32x2_t



impl UnwindSafe for int32x2x2_t



impl UnwindSafe for int32x2x3_t



impl UnwindSafe for int32x2x4_t



impl UnwindSafe for int32x4_t



impl UnwindSafe for int32x4x2_t



impl UnwindSafe for int32x4x3_t



impl UnwindSafe for int32x4x4_t



impl UnwindSafe for int64x1_t



impl UnwindSafe for int64x1x2_t



impl UnwindSafe for int64x1x3_t



impl UnwindSafe for int64x1x4_t



impl UnwindSafe for int64x2_t



impl UnwindSafe for int64x2x2_t



impl UnwindSafe for int64x2x3_t



impl UnwindSafe for int64x2x4_t



impl UnwindSafe for isize



impl UnwindSafe for m128



impl UnwindSafe for m256



impl UnwindSafe for m128d



impl UnwindSafe for m128i



impl UnwindSafe for m256d



impl UnwindSafe for m256i



impl UnwindSafe for objc_class



impl UnwindSafe for objc_selector



impl UnwindSafe for poly8x8_t



impl UnwindSafe for poly8x8x2_t



impl UnwindSafe for poly8x8x3_t



impl UnwindSafe for poly8x8x4_t



impl UnwindSafe for poly8x16_t



impl UnwindSafe for poly8x16x2_t



impl UnwindSafe for poly8x16x3_t



impl UnwindSafe for poly8x16x4_t



impl UnwindSafe for poly16x4_t



impl UnwindSafe for poly16x4x2_t



impl UnwindSafe for poly16x4x3_t



impl UnwindSafe for poly16x4x4_t



impl UnwindSafe for poly16x8_t



impl UnwindSafe for poly16x8x2_t



impl UnwindSafe for poly16x8x3_t



impl UnwindSafe for poly16x8x4_t



impl UnwindSafe for poly64x1_t



impl UnwindSafe for poly64x1x2_t



impl UnwindSafe for poly64x1x3_t



impl UnwindSafe for poly64x1x4_t



impl UnwindSafe for poly64x2_t



impl UnwindSafe for poly64x2x2_t



impl UnwindSafe for poly64x2x3_t



impl UnwindSafe for poly64x2x4_t



impl UnwindSafe for str



impl UnwindSafe for svbool_t



impl UnwindSafe for svfloat32_t



impl UnwindSafe for svfloat32x2_t



impl UnwindSafe for svfloat32x3_t



impl UnwindSafe for svfloat32x4_t



impl UnwindSafe for svfloat64_t



impl UnwindSafe for svfloat64x2_t



impl UnwindSafe for svfloat64x3_t



impl UnwindSafe for svfloat64x4_t



impl UnwindSafe for svint8_t



impl UnwindSafe for svint8x2_t



impl UnwindSafe for svint8x3_t



impl UnwindSafe for svint8x4_t



impl UnwindSafe for svint16_t



impl UnwindSafe for svint16x2_t



impl UnwindSafe for svint16x3_t



impl UnwindSafe for svint16x4_t



impl UnwindSafe for svint32_t



impl UnwindSafe for svint32x2_t



impl UnwindSafe for svint32x3_t



impl UnwindSafe for svint32x4_t



impl UnwindSafe for svint64_t



impl UnwindSafe for svint64x2_t



impl UnwindSafe for svint64x3_t



impl UnwindSafe for svint64x4_t



impl UnwindSafe for svpattern



impl UnwindSafe for svprfop



impl UnwindSafe for svuint8_t



impl UnwindSafe for svuint8x2_t



impl UnwindSafe for svuint8x3_t



impl UnwindSafe for svuint8x4_t



impl UnwindSafe for svuint16_t



impl UnwindSafe for svuint16x2_t



impl UnwindSafe for svuint16x3_t



impl UnwindSafe for svuint16x4_t



impl UnwindSafe for svuint32_t



impl UnwindSafe for svuint32x2_t



impl UnwindSafe for svuint32x3_t



impl UnwindSafe for svuint32x4_t



impl UnwindSafe for svuint64_t



impl UnwindSafe for svuint64x2_t



impl UnwindSafe for svuint64x3_t



impl UnwindSafe for svuint64x4_t



impl UnwindSafe for u8



impl UnwindSafe for u16



impl UnwindSafe for u32



impl UnwindSafe for u64



impl UnwindSafe for u128



impl UnwindSafe for uint8x8_t



impl UnwindSafe for uint8x8x2_t



impl UnwindSafe for uint8x8x3_t



impl UnwindSafe for uint8x8x4_t



impl UnwindSafe for uint8x16_t



impl UnwindSafe for uint8x16x2_t



impl UnwindSafe for uint8x16x3_t



impl UnwindSafe for uint8x16x4_t



impl UnwindSafe for uint16x4_t



impl UnwindSafe for uint16x4x2_t



impl UnwindSafe for uint16x4x3_t



impl UnwindSafe for uint16x4x4_t



impl UnwindSafe for uint16x8_t



impl UnwindSafe for uint16x8x2_t



impl UnwindSafe for uint16x8x3_t



impl UnwindSafe for uint16x8x4_t



impl UnwindSafe for uint32x2_t



impl UnwindSafe for uint32x2x2_t



impl UnwindSafe for uint32x2x3_t



impl UnwindSafe for uint32x2x4_t



impl UnwindSafe for uint32x4_t



impl UnwindSafe for uint32x4x2_t



impl UnwindSafe for uint32x4x3_t



impl UnwindSafe for uint32x4x4_t



impl UnwindSafe for uint64x1_t



impl UnwindSafe for uint64x1x2_t



impl UnwindSafe for uint64x1x3_t



impl UnwindSafe for uint64x1x4_t



impl UnwindSafe for uint64x2_t



impl UnwindSafe for uint64x2x2_t



impl UnwindSafe for uint64x2x3_t



impl UnwindSafe for uint64x2x4_t



impl UnwindSafe for usize



impl UnwindSafe for v128



impl UnwindSafe for core::arch::powerpc::vector_bool_char



impl UnwindSafe for core::arch::s390x::vector_bool_char



impl UnwindSafe for core::arch::powerpc::vector_bool_int



impl UnwindSafe for core::arch::s390x::vector_bool_int



impl UnwindSafe for vector_bool_long



impl UnwindSafe for vector_bool_long_long



impl UnwindSafe for core::arch::powerpc::vector_bool_short



impl UnwindSafe for core::arch::s390x::vector_bool_short



impl UnwindSafe for core::arch::powerpc::vector_double



impl UnwindSafe for core::arch::s390x::vector_double



impl UnwindSafe for core::arch::powerpc::vector_float



impl UnwindSafe for core::arch::s390x::vector_float



impl UnwindSafe for core::arch::powerpc::vector_signed_char



impl UnwindSafe for core::arch::s390x::vector_signed_char



impl UnwindSafe for core::arch::powerpc::vector_signed_int



impl UnwindSafe for core::arch::s390x::vector_signed_int



impl UnwindSafe for vector_signed_long



impl UnwindSafe for vector_signed_long_long



impl UnwindSafe for core::arch::powerpc::vector_signed_short



impl UnwindSafe for core::arch::s390x::vector_signed_short



impl UnwindSafe for core::arch::powerpc::vector_unsigned_char



impl UnwindSafe for core::arch::s390x::vector_unsigned_char



impl UnwindSafe for core::arch::powerpc::vector_unsigned_int



impl UnwindSafe for core::arch::s390x::vector_unsigned_int



impl UnwindSafe for vector_unsigned_long



impl UnwindSafe for vector_unsigned_long_long



impl UnwindSafe for core::arch::powerpc::vector_unsigned_short



impl UnwindSafe for core::arch::s390x::vector_unsigned_short



impl<'a, 'b, const N: usize> UnwindSafe for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> !UnwindSafe for DebugList<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugMap<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugSet<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugStruct<'a, 'b>



impl<'a, 'b> !UnwindSafe for DebugTuple<'a, 'b>



impl<'a, 'b> UnwindSafe for CharSliceSearcher<'a, 'b>



impl<'a, 'b> UnwindSafe for StrSearcher<'a, 'b>



impl<'a, A> !UnwindSafe for core::option::IterMut<'a, A>



impl<'a, A> UnwindSafe for core::option::Iter<'a, A>
where A: RefUnwindSafe,



impl<'a, F> UnwindSafe for CharPredicateSearcher<'a, F>
where F: UnwindSafe,



impl<'a, I> !UnwindSafe for ByRefSized<'a, I>



impl<'a, P> UnwindSafe for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for core::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, P> UnwindSafe for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: UnwindSafe,



impl<'a, T, P> !UnwindSafe for ChunkByMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for RSplitNMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitInclusiveMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitMut<'a, T, P>



impl<'a, T, P> !UnwindSafe for SplitNMut<'a, T, P>



impl<'a, T, P> UnwindSafe for ChunkBy<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::RSplit<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::RSplitN<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::Split<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::SplitInclusive<'a, T, P>



impl<'a, T, P> UnwindSafe for core::slice::SplitN<'a, T, P>



impl<'a, T, const N: usize> UnwindSafe for ArrayWindows<'a, T, N>
where T: RefUnwindSafe,



impl<'a, T> !UnwindSafe for BorrowedCursor<'a, T>



impl<'a, T> !UnwindSafe for ChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for ChunksMut<'a, T>



impl<'a, T> !UnwindSafe for core::result::IterMut<'a, T>



impl<'a, T> !UnwindSafe for core::slice::IterMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksExactMut<'a, T>



impl<'a, T> !UnwindSafe for RChunksMut<'a, T>



impl<'a, T> UnwindSafe for Chunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for ChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for core::result::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for core::slice::Iter<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunks<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for RChunksExact<'a, T>
where T: RefUnwindSafe,



impl<'a, T> UnwindSafe for Windows<'a, T>
where T: RefUnwindSafe,



impl<'a, const N: usize> UnwindSafe for CharArraySearcher<'a, N>



impl<'a> !UnwindSafe for ContextBuilder<'a>



impl<'a> !UnwindSafe for Formatter<'a>



impl<'a> !UnwindSafe for IoSliceMut<'a>



impl<'a> !UnwindSafe for Request<'a>



impl<'a> !UnwindSafe for Source<'a>



impl<'a> UnwindSafe for Arguments<'a>



impl<'a> UnwindSafe for core::ffi::c_str::Bytes<'a>



impl<'a> UnwindSafe for core::str::Bytes<'a>



impl<'a> UnwindSafe for CharIndices<'a>



impl<'a> UnwindSafe for CharSearcher<'a>



impl<'a> UnwindSafe for Chars<'a>



impl<'a> UnwindSafe for Context<'a>



impl<'a> UnwindSafe for EncodeUtf16<'a>



impl<'a> UnwindSafe for EscapeAscii<'a>



impl<'a> UnwindSafe for core::str::EscapeDebug<'a>



impl<'a> UnwindSafe for core::str::EscapeDefault<'a>



impl<'a> UnwindSafe for core::str::EscapeUnicode<'a>



impl<'a> UnwindSafe for IoSlice<'a>



impl<'a> UnwindSafe for Lines<'a>



impl<'a> UnwindSafe for LinesAny<'a>



impl<'a> UnwindSafe for Location<'a>



impl<'a> UnwindSafe for PanicInfo<'a>



impl<'a> UnwindSafe for PanicMessage<'a>



impl<'a> UnwindSafe for PhantomContravariantLifetime<'a>



impl<'a> UnwindSafe for PhantomCovariantLifetime<'a>



impl<'a> UnwindSafe for PhantomInvariantLifetime<'a>



impl<'a> UnwindSafe for SplitAsciiWhitespace<'a>



impl<'a> UnwindSafe for SplitWhitespace<'a>



impl<'a> UnwindSafe for Utf8Chunk<'a>



impl<'a> UnwindSafe for Utf8Chunks<'a>



impl<'a> UnwindSafe for Utf8Pattern<'a>



impl<'a> UnwindSafe for VaList<'a>



impl<'b, T> !UnwindSafe for Ref<'b, T>



impl<'b, T> !UnwindSafe for RefMut<'b, T>



impl<'data, T> !UnwindSafe for BorrowedBuf<'data, T>



impl<A, B> UnwindSafe for core::iter::Chain<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<A, B> UnwindSafe for Zip<A, B>
where A: UnwindSafe, B: UnwindSafe,



impl<A> UnwindSafe for core::option::IntoIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for OptionFlatten<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeFromIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeInclusiveIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RangeIter<A>
where A: UnwindSafe,



impl<A> UnwindSafe for core::iter::Repeat<A>
where A: UnwindSafe,



impl<A> UnwindSafe for RepeatN<A>
where A: UnwindSafe,



impl<B, C> UnwindSafe for ControlFlow<B, C>
where C: UnwindSafe, B: UnwindSafe,



impl<Dyn> !UnwindSafe for DynMetadata<Dyn>



impl<F> UnwindSafe for core::iter::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for core::fmt::FromFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for OnceWith<F>
where F: UnwindSafe,



impl<F> UnwindSafe for PollFn<F>
where F: UnwindSafe,



impl<F> UnwindSafe for RepeatWith<F>
where F: UnwindSafe,



impl<G> UnwindSafe for FromCoroutine<G>
where G: UnwindSafe,



impl<H> UnwindSafe for BuildHasherDefault<H>



impl<I, F, const N: usize> UnwindSafe for MapWindows<I, F, N>
where F: UnwindSafe, I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I, F> UnwindSafe for FilterMap<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for Inspect<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, F> UnwindSafe for Map<I, F>
where I: UnwindSafe, F: UnwindSafe,



impl<I, G> UnwindSafe for IntersperseWith<I, G>
where G: UnwindSafe, I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I, P> UnwindSafe for Filter<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for MapWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for SkipWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, P> UnwindSafe for TakeWhile<I, P>
where I: UnwindSafe, P: UnwindSafe,



impl<I, St, F> UnwindSafe for Scan<I, St, F>
where I: UnwindSafe, F: UnwindSafe, St: UnwindSafe,



impl<I, U, F> UnwindSafe for FlatMap<I, U, F>



impl<I, const N: usize> UnwindSafe for ArrayChunks<I, N>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I> UnwindSafe for Cloned<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Copied<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Cycle<I>
where I: UnwindSafe,



impl<I> UnwindSafe for DecodeUtf16<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Enumerate<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Flatten<I>



impl<I> UnwindSafe for FromIter<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Fuse<I>
where I: UnwindSafe,



impl<I> UnwindSafe for Intersperse<I>
where <I as Iterator>::Item: Sized + UnwindSafe, I: UnwindSafe,



impl<I> UnwindSafe for Peekable<I>
where I: UnwindSafe, <I as Iterator>::Item: UnwindSafe,



impl<I> UnwindSafe for Skip<I>
where I: UnwindSafe,



impl<I> UnwindSafe for StepBy<I>
where I: UnwindSafe,



impl<I> UnwindSafe for core::iter::Take<I>
where I: UnwindSafe,



impl<Idx> UnwindSafe for Clamp<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::Range<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::RangeFrom<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::RangeInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for RangeTo<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::ops::RangeToInclusive<Idx>
where Idx: UnwindSafe,



impl<Idx> UnwindSafe for core::range::RangeToInclusive<Idx>
where Idx: UnwindSafe,



impl<P> UnwindSafe for MaybeDangling<P>
where P: UnwindSafe + ?Sized,



impl<Ptr> UnwindSafe for Pin<Ptr>
where Ptr: UnwindSafe,



impl<Ret, T> UnwindSafe for fn(Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™) -> Ret



impl<T, E> UnwindSafe for Result<T, E>
where T: UnwindSafe, E: UnwindSafe,



impl<T, F> UnwindSafe for DropGuard<T, F>
where T: UnwindSafe, F: UnwindSafe,



impl<T, F> UnwindSafe for LazyCell<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, F> UnwindSafe for Successors<T, F>
where F: UnwindSafe, T: UnwindSafe,



impl<T, U> UnwindSafe for core::io::Chain<T, U>
where T: UnwindSafe, U: UnwindSafe,



impl<T, const N: usize> UnwindSafe for core::array::IntoIter<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Mask<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for Simd<T, N>
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for [MaybeUninit<T>; N]
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for [Option<T>; N]
where T: UnwindSafe,



impl<T, const N: usize> UnwindSafe for [T; N]
where T: UnwindSafe,



impl<T, const VARIANT: u32, const FIELD: u32> UnwindSafe for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<T> !UnwindSafe for TraitImpl<T>



impl<T> UnwindSafe for (Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™)
where T: UnwindSafe,



impl<T> UnwindSafe for Atomic<T>



impl<T> UnwindSafe for Bound<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Cell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Cursor<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Discriminant<T>



impl<T> UnwindSafe for core::iter::Empty<T>



impl<T> UnwindSafe for core::result::IntoIter<T>
where T: UnwindSafe,



impl<T> UnwindSafe for ManuallyDrop<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for MaybeUninit<T>
where T: UnwindSafe,



impl<T> UnwindSafe for NumBuffer<T>



impl<T> UnwindSafe for Once<T>
where T: UnwindSafe,



impl<T> UnwindSafe for OnceCell<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Option<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Pending<T>



impl<T> UnwindSafe for PhantomContravariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomCovariant<T>
where T: ?Sized,



impl<T> UnwindSafe for PhantomData<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for PhantomInvariant<T>
where T: ?Sized,



impl<T> UnwindSafe for Poll<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Ready<T>
where T: UnwindSafe,



impl<T> UnwindSafe for RefCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Rev<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Reverse<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Saturating<T>
where T: UnwindSafe,



impl<T> UnwindSafe for SyncUnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for SyncView<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for core::io::Take<T>
where T: UnwindSafe,



impl<T> UnwindSafe for UnsafeCell<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for UnsafePinned<T>
where T: UnwindSafe + ?Sized,



impl<T> UnwindSafe for Wrapping<T>
where T: UnwindSafe,



impl<T> UnwindSafe for Yeet<T>
where T: UnwindSafe,



impl<T> UnwindSafe for [T]
where T: UnwindSafe,



impl<Y, R> UnwindSafe for CoroutineState<Y, R>
where Y: UnwindSafe, R: UnwindSafe,



impl<const N: usize> UnwindSafe for [u8; N]